@@ -19,8 +19,9 @@ from peek_platform import PeekPlatformConfig
 from peek_platform.util.LogUtil import (
     setupPeekLogger,
     updatePeekLoggerHandlers,
-    setupLoggingToSysloyServer,
+    setupLoggingToSyslogServer,
 )
+from peek_platform.util.ManHoleUtil import start_manhole
 from peek_plugin_base.PeekVortexUtil import peekWorkerName, peekServerName
 from pytmpdir.dir_setting import DirSetting
 from twisted.internet import reactor, defer
@@ -71,13 +72,12 @@ def setupPlatform():
     logging.root.setLevel(PeekPlatformConfig.config.loggingLevel)
     updatePeekLoggerHandlers(
         PeekPlatformConfig.componentName,
-        PeekPlatformConfig.config.loggingRotateSizeMb,
-        PeekPlatformConfig.config.loggingRotationsToKeep,
+        PeekPlatformConfig.config.daysToKeep,
         PeekPlatformConfig.config.logToStdout,
     )
 
     if PeekPlatformConfig.config.loggingLogToSyslogHost:
-        setupLoggingToSysloyServer(
+        setupLoggingToSyslogServer(
             PeekPlatformConfig.config.loggingLogToSyslogHost,
             PeekPlatformConfig.config.loggingLogToSyslogPort,
             PeekPlatformConfig.config.loggingLogToSyslogFacility,
@@ -112,6 +112,15 @@ def setupPlatform():
 
     configureCeleryApp(celeryApp, PeekPlatformConfig.config)
 
+    # Setup manhole
+    if PeekPlatformConfig.config.manholeEnabled:
+        start_manhole(
+            PeekPlatformConfig.config.manholePort,
+            PeekPlatformConfig.config.manholePassword,
+            PeekPlatformConfig.config.manholePublicKeyFile,
+            PeekPlatformConfig.config.manholePrivateKeyFile,
+        )
+
 
 def twistedMain():
     # defer.setDebugging(True)
